==> nuclearstate-0.0.1.tar.gz: nuclearstate-0.0.1/nuclearstate/src/nuclearstate.py <==
# %%
link = {}
derives = []
eventFormat = 'on_'
messageFormat = 'receive_'
mode = 'implicit'
eventReceipts = {}
messageReceipts = {}

def init(newlink):
    global link
    link = newlink

def alias(func, *names):
    for name in names:
        globals()[name] = lambda *args: func(*args)

def format(event='on_', message='receive_'):
    global eventFormat
    global messageFormat
    eventFormat = event
    messageFormat = message

def eventMode(new):
    global mode
    mode = new

def event_r(eventName, obj):
    global eventReceipts
    if eventName in eventReceipts:
        eventReceipts[eventName].append(obj)
    else:
        eventReceipts[eventName] = [obj]

def message_r(messageName, obj):
    global messageReceipts
    if messageName in messageReceipts:
        messageReceipts[messageName].append(obj)
    else:
        messageReceipts[messageName] = [obj]

def broadcast_change():
    for derive in derives:
        old_val = derive.previous_value
        new_val = derive.get()
        if old_val != new_val:
            derive.run_reacts()

def log1(content):
    print(f'Test2 Changed to {content}')
def log2(content):
    print(f'Test4 Changed to {content}')

class Base:
    def __init__(self, value):
        self.value = value
    def set(self, new):
        self.value = new
        broadcast_change()
    def get(self):
        return self.value

class Derive:
    def __init__(self, source):
        self.source = source
        self.previous_value = self.get()
        derives.append(self)
        self.reacts = []
    def set(self, new):
        self.source = new
    def get(self):
        self.previous_value = self.source()
        return self.source()
    def run_reacts(self):
        for react in self.reacts:
            react(self.get())
    def react(self, new):
        self.reacts.append(new)
        return self
    def react_to_change(self, new):
        self.react(new)

class Receiver:
    pass

def broadcast(event):
    global mode
    global eventFormat
    if mode == 'implicit':
        global link
        funcname = f'{eventFormat}{event}'
        for obj in link:
            if isinstance(link[obj], Receiver):
                if funcname in dir(link[obj]):
                    getattr(link[obj], funcname)()
    elif mode == 'explicit':
        global eventReceipts
        targetReceipt = eventReceipts[event]
        funcname = f'{eventFormat}{event}'
        for obj in targetReceipt:
            if isinstance(obj, Receiver):
                if funcname in dir(obj):
                    getattr(obj, funcname)()

def send(message, data):
    global mode
    global messageFormat
    if mode == 'implicit':
        global link
        funcname = f'{messageFormat}{message}'
        for obj in link:
            if isinstance(link[obj], Receiver):
                if funcname in dir(link[obj]):
                    getattr(link[obj], funcname)(data)
    elif mode == 'explicit':
        global messageReceipts
        targetReceipt = messageReceipts[message]
        funcname = f'{messageFormat}{message}'
        for obj in targetReceipt:
            if isinstance(obj, Receiver):
                if funcname in dir(obj):
                    getattr(obj, funcname)(data)
            
alias(Base, 'atom')
alias(Derive, 'derive')

==> nuclearstate-0.1.1.tar.gz: nuclearstate-0.1.1/nuclearstate/src/nuclearstate.py <==
# %%
link = {}
derives = []
eventFormat = 'on_'
messageFormat = 'receive_'
mode = 'implicit'
eventReceipts = {}
messageReceipts = {}
scanned = False

def init(newlink):
    global link
    link = newlink

def alias(func, *names):
    for name in names:
        globals()[name] = lambda *args: func(*args)

def format(event='on_', message='receive_'):
    global eventFormat
    global messageFormat
    eventFormat = event
    messageFormat = message

def eventMode(new):
    global mode
    mode = new

def event_r(eventName, obj):
    global eventReceipts
    if eventName in eventReceipts:
        eventReceipts[eventName].append(obj)
    else:
        eventReceipts[eventName] = [obj]

def message_r(messageName, obj):
    global messageReceipts
    if messageName in messageReceipts:
        messageReceipts[messageName].append(obj)
    else:
        messageReceipts[messageName] = [obj]

def broadcast_change():
    for derive in derives:
        old_val = derive.previous_value
        new_val = derive.get()
        if old_val != new_val:
            derive.run_reacts()

def log1(content):
    print(f'Test2 Changed to {content}')
def log2(content):
    print(f'Test4 Changed to {content}')

class Base:
    def __init__(self, value):
        self.value = value
    def set(self, new):
        self.value = new
        broadcast_change()
    def get(self):
        return self.value

class Derive:
    def __init__(self, source):
        self.source = source
        self.previous_value = self.get()
        derives.append(self)
        self.reacts = []
    def set(self, new):
        self.source = new
    def get(self):
        self.previous_value = self.source()
        return self.source()
    def run_reacts(self):
        for react in self.reacts:
            react(self.get())
    def react(self, new):
        self.reacts.append(new)
        return self
    def react_to_change(self, new):
        self.react(new)

class Receiver:
    pass

def broadcast(event):
    global mode
    global eventFormat
    global scanned
    if mode == 'implicit':
        global link
        funcname = f'{eventFormat}{event}'
        for obj in link:
            if isinstance(link[obj], Receiver):
                if funcname in dir(link[obj]):
                    getattr(link[obj], funcname)()
    elif mode == 'explicit' or mode == 'described':
        global eventReceipts
        targetReceipt = eventReceipts[event]
        funcname = f'{eventFormat}{event}'
        for obj in targetReceipt:
            if isinstance(obj, Receiver):
                if funcname in dir(obj):
                    getattr(obj, funcname)()
    elif mode == 'predicted':
        if scanned:
            targetReceipt = eventReceipts[event]
            funcname = f'{eventFormat}{event}'
            for obj in targetReceipt:
                if isinstance(obj, Receiver):
                    if funcname in dir(obj):
                        getattr(obj, funcname)()
        else:
            scan()
            scanned = True
            broadcast(event)

def send(message, data):
    global mode
    global messageFormat
    if mode == 'implicit':
        global link
        funcname = f'{messageFormat}{message}'
        for obj in link:
            if isinstance(link[obj], Receiver):
                if funcname in dir(link[obj]):
                    getattr(link[obj], funcname)(data)
    elif mode == 'explicit' or mode == 'described':
        global messageReceipts
        targetReceipt = messageReceipts[message]
        funcname = f'{messageFormat}{message}'
        for obj in targetReceipt:
            if isinstance(obj, Receiver):
                if funcname in dir(obj):
                    getattr(obj, funcname)(data)
    elif mode == 'predicted':
        global scanned
        if scanned:
            targetReceipt = messageReceipts[message]
            funcname = f'{messageFormat}{message}'
            for obj in targetReceipt:
                if isinstance(obj, Receiver):
                    if funcname in dir(obj):
                        getattr(obj, funcname)(data)
        else:
            scan()
            scanned = True
            send(message, data)

def startswith(text, sub):
    return text[:len(sub)] == sub

def removeend(text, toremove):
    return text[len(toremove):]

def scan():
    global eventReceipts
    global messageReceipts
    global link
    global eventFormat
    global messageFormat
    for obj in link:
        if isinstance(link[obj], Receiver):
            for func in dir(link[obj]):
                if startswith(func, eventFormat):
                    event_r(removeend(func, eventFormat), link[obj])
                elif startswith(func, messageFormat):
                    message_r(removeend(func, messageFormat), link[obj])

alias(Base, 'atom')
alias(Derive, 'derive')
